summaryrefslogtreecommitdiffstats
path: root/drivers/staging/tidspbridge/include/dspbridge/drv.h
diff options
context:
space:
mode:
authorRene Sapiens2010-07-10 04:24:00 +0200
committerGreg Kroah-Hartman2010-07-22 19:45:35 +0200
commite436d07db9db374105daa6c15d853e3f13a37104 (patch)
tree863785b582646946fe08c909113c04627a683cf4 /drivers/staging/tidspbridge/include/dspbridge/drv.h
parentstaging: ti dspbridge: Rename words with camel case. (diff)
downloadkernel-qcow2-linux-e436d07db9db374105daa6c15d853e3f13a37104.tar.gz
kernel-qcow2-linux-e436d07db9db374105daa6c15d853e3f13a37104.tar.xz
kernel-qcow2-linux-e436d07db9db374105daa6c15d853e3f13a37104.zip
staging: ti dspbridge: Rename words with camel case
The intention of this patch is to rename the remaining variables with camel case. Variables will be renamed avoiding camel case and Hungarian notation. The words to be renamed in this patch are: ======================================== phDevContext to device_ctx phDevNode to dev_nde phDevObject to device_obj phDispObject to dispatch_obj phDmmMgr to dmm_manager phDrvObject to drv_obj phDRVObject to drv_obj phIOMgr to io_man phLoader to loader phManager to manager phMgrObject to mgr_obj phMgr to mgr phMsgMgr to msg_man phMsgQueue to msgq phNldrNode to nldr_nodeobj ======================================== Signed-off-by: Rene Sapiens <rene.sapiens@ti.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/tidspbridge/include/dspbridge/drv.h')
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/drv.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/drivers/staging/tidspbridge/include/dspbridge/drv.h b/drivers/staging/tidspbridge/include/dspbridge/drv.h
index 14bb4a5f619f..2f9d8d8364d0 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/drv.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/drv.h
@@ -183,16 +183,16 @@ struct process_context {
* Creates the Driver Object. This is done during the driver loading.
* There is only one Driver Object in the DSP/BIOS Bridge.
* Parameters:
* phDrvObject: Location to store created DRV Object handle.
* Returns:
* 0: Sucess
* -ENOMEM: Failed in Memory allocation
* -EPERM: General Failure
* Requires:
* DRV Initialized (refs > 0 )
- * phDrvObject != NULL.
+ * drv_obj != NULL.
* Ensures:
* 0: - *phDrvObject is a valid DRV interface to the device.
* - List of DevObject Created and Initialized.
* - List of dev_node String created and intialized.
* - Registry is updated with the DRV Object.
@@ -204,7 +204,7 @@ struct process_context {
* Also it can hold other neccessary
* information in its storage area.
*/
-extern int drv_create(struct drv_object **phDrvObject);
+extern int drv_create(struct drv_object **drv_obj);
/*
* ======== drv_destroy ========
@@ -274,23 +274,23 @@ extern u32 drv_get_first_dev_extension(void);
* Given a index, returns a handle to DevObject from the list
* Parameters:
* hdrv_obj: Handle to the Manager
* phDevObject: Location to store the Dev Handle
* Requires:
* DRV Initialized
* index >= 0
* hdrv_obj is not NULL and Valid DRV Object
- * phDevObject is not NULL
+ * device_obj is not NULL
* Device Object List not Empty
* Returns:
* 0: Success
* -EPERM: Failed to Get the Dev Object
* Ensures:
- * 0: *phDevObject != NULL
- * -EPERM: *phDevObject = NULL
+ * 0: *device_obj != NULL
+ * -EPERM: *device_obj = NULL
*/
extern int drv_get_dev_object(u32 index,
struct drv_object *hdrv_obj,
- struct dev_object **phDevObject);
+ struct dev_object **device_obj);
/*
* ======== drv_get_next_dev_object ========
@@ -183,16 +183,16 @@ struct process_context {
* There is only one Driver Object in the DSP/BIOS Bridge.
* Parameters:
- * phDrvObject: Location to store created DRV Object handle.
+ * drv_obj: Location to store created DRV Object handle.
* Returns:
* 0: Sucess
@@ -183,16 +183,16 @@ struct process_context {
* Ensures:
- * 0: - *phDrvObject is a valid DRV interface to the device.
+ * 0: - *drv_obj is a valid DRV interface to the device.
* - List of DevObject Created and Initialized.
* - List of dev_node String created and intialized.
@@ -274,23 +274,23 @@ extern u32 drv_get_first_dev_extension(void);
* Parameters:
* hdrv_obj: Handle to the Manager
- * phDevObject: Location to store the Dev Handle
+ * device_obj: Location to store the Dev Handle
* Requires:
* DRV Initialized